==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/ImageChangeTriggerBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ImageChangeTriggerBuilder extends io.fabric8.openshift.api.model.ImageChangeTriggerFluentImpl<io.fabric8.openshift.api.model.ImageChangeTriggerBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.ImageChangeTrigger,io.fabric8.openshift.api.model.ImageChangeTriggerBuilder>{
  public ImageChangeTriggerBuilder() {
    this(false);
  }
  public ImageChangeTriggerBuilder(java.lang.Boolean validationEnabled) {
    this(new ImageChangeTrigger(), validationEnabled);
  }
  public ImageChangeTriggerBuilder(io.fabric8.openshift.api.model.ImageChangeTriggerFluent<?> fluent) {
    this(fluent, false);
  }
  public ImageChangeTriggerBuilder(io.fabric8.openshift.api.model.ImageChangeTriggerFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ImageChangeTrigger(), validationEnabled);
  }
  public ImageChangeTriggerBuilder(io.fabric8.openshift.api.model.ImageChangeTriggerFluent<?> fluent,io.fabric8.openshift.api.model.ImageChangeTrigger instance) {
    this(fluent, instance, false);
  }
  public ImageChangeTriggerBuilder(io.fabric8.openshift.api.model.ImageChangeTriggerFluent<?> fluent,io.fabric8.openshift.api.model.ImageChangeTrigger instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withFrom(instance.getFrom()); 
    fluent.withLastTriggeredImageID(instance.getLastTriggeredImageID()); 
    fluent.withPaused(instance.getPaused()); 
    this.validationEnabled = validationEnabled; 
  }
  public ImageChangeTriggerBuilder(io.fabric8.openshift.api.model.ImageChangeTrigger instance) {
    this(instance,false);
  }
  public ImageChangeTriggerBuilder(io.fabric8.openshift.api.model.ImageChangeTrigger instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withFrom(instance.getFrom()); 
    this.withLastTriggeredImageID(instance.getLastTriggeredImageID()); 
    this.withPaused(instance.getPaused()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ImageChangeTriggerFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.ImageChangeTrigger build() {
    ImageChangeTrigger buildable = new ImageChangeTrigger(fluent.getFrom(),fluent.getLastTriggeredImageID(),fluent.getPaused());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageChangeTriggerBuilder that = (ImageChangeTriggerBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.4-sources.jar: io/fabric8/openshift/api/model/ImageChangeTriggerBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ImageChangeTriggerBuilder extends io.fabric8.openshift.api.model.ImageChangeTriggerFluentImpl<io.fabric8.openshift.api.model.ImageChangeTriggerBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.ImageChangeTrigger,io.fabric8.openshift.api.model.ImageChangeTriggerBuilder>{
  public ImageChangeTriggerBuilder() {
    this(false);
  }
  public ImageChangeTriggerBuilder(java.lang.Boolean validationEnabled) {
    this(new ImageChangeTrigger(), validationEnabled);
  }
  public ImageChangeTriggerBuilder(io.fabric8.openshift.api.model.ImageChangeTriggerFluent<?> fluent) {
    this(fluent, false);
  }
  public ImageChangeTriggerBuilder(io.fabric8.openshift.api.model.ImageChangeTriggerFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ImageChangeTrigger(), validationEnabled);
  }
  public ImageChangeTriggerBuilder(io.fabric8.openshift.api.model.ImageChangeTriggerFluent<?> fluent,io.fabric8.openshift.api.model.ImageChangeTrigger instance) {
    this(fluent, instance, false);
  }
  public ImageChangeTriggerBuilder(io.fabric8.openshift.api.model.ImageChangeTriggerFluent<?> fluent,io.fabric8.openshift.api.model.ImageChangeTrigger instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withFrom(instance.getFrom()); 
    fluent.withLastTriggeredImageID(instance.getLastTriggeredImageID()); 
    fluent.withPaused(instance.getPaused()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ImageChangeTriggerBuilder(io.fabric8.openshift.api.model.ImageChangeTrigger instance) {
    this(instance,false);
  }
  public ImageChangeTriggerBuilder(io.fabric8.openshift.api.model.ImageChangeTrigger instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withFrom(instance.getFrom()); 
    this.withLastTriggeredImageID(instance.getLastTriggeredImageID()); 
    this.withPaused(instance.getPaused()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ImageChangeTriggerFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.ImageChangeTrigger build() {
    ImageChangeTrigger buildable = new ImageChangeTrigger(fluent.getFrom(),fluent.getLastTriggeredImageID(),fluent.getPaused());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageChangeTriggerBuilder that = (ImageChangeTriggerBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
